import { Schedule } from 'aws-cdk-lib/aws-events';
import { Bucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * Properties related to forwarding messages to Slack.
 */
export interface SlackProperties {
    /** The Slack webhook used to send messages. Details on setting up a webhook can be found at https://api.slack.com/messaging/webhooks.
     *  @experimental
    */
    readonly webhook: string;
}
/**
 * Properties related to forwarding messages via mail.
 */
export interface MailProperties {
    readonly subscribers: Array<string>;
}
/**
 * Types of available Gradle distributions.
 */
export declare enum GradleDistribution {
    /**
     * Binaries only.
     */
    BIN = 0,
    /**
     * Binaries, sources and documentation.
     */
    ALL = 1,
    /**
     * BINARY and ALL.
     */
    BOTH = 2
}
export interface UploaderProperties {
    /**
     * Optional properties required for sending messages via Slack.
     */
    readonly slackProperties?: SlackProperties;
    /**
     * Optional properties required for sending messages via mail.
     */
    readonly mailProperties?: MailProperties;
    readonly whitelist: Array<string>;
    readonly schedule?: Schedule;
    /**
     * The {@link GradleDistribution | Gradle distribution} type to download. If no value is specified, only the binaries will be downloaded.
     */
    readonly distribution?: GradleDistribution;
}
export declare class GradleUploader extends Construct {
    constructor(scope: Construct, id: string, uploaderProperties: UploaderProperties);
    private createTrigger;
    private createFunction;
    private createLambdaLayer;
    /**
     * Add mail subscriptions to the SNS topic.
     * @param subscriber The mail addresses to add to the SNS topic as subscriber.
     */
    private addSubscribers;
    private createTopic;
    createBucket(whitelist: Array<string>): Bucket;
}
